@@ -1,9 +1,9 @@
 ##
 #     Project: gWakeOnLAN
 # Description: Wake up your machines using Wake on LAN
-#      Author: Fabio Castelli (Muflone) <muflone@vbsimple.net>
-#   Copyright: 2009-2014 Fabio Castelli
-#     License: GPL-2+
+#      Author: Fabio Castelli (Muflone) <muflone@muflone.com>
+#   Copyright: 2009-2020 Fabio Castelli
+#     License: GPL-3+
 #  This program is free software; you can redistribute it and/or modify it
 #  under the terms of the GNU General Public License as published by the Free
 #  Software Foundation; either version 2 of the License, or (at your option)
@@ -20,18 +20,21 @@
 
 import sys
 import os.path
-from xdg import BaseDirectory
+
+import xdg.BaseDirectory
+
 
 # Application constants
 APP_NAME = 'gWakeOnLAN'
-APP_VERSION = '0.6.3'
+APP_VERSION = '0.7.0'
 APP_DESCRIPTION = 'Wake up your machines using Wake on LAN.'
 APP_ID = 'gwakeonlan.muflone.com'
-APP_URL = 'http://www.muflone.com/gwakeonlan'
+APP_URL = 'https://www.muflone.com/gwakeonlan'
 APP_AUTHOR = 'Fabio Castelli'
-APP_AUTHOR_EMAIL = 'muflone@vbsimple.net'
-APP_COPYRIGHT = 'Copyright 2009-2014 %s' % APP_AUTHOR
+APP_AUTHOR_EMAIL = 'muflone@muflone.com'
+APP_COPYRIGHT = 'Copyright 2009-2020 %s' % APP_AUTHOR
 # Other constants
+DEFAULT_UDP_PORT = 9
 BROADCAST_ADDRESS = '255.255.255.255'
 DOMAIN_NAME = 'gwakeonlan'
 VERBOSE_LEVEL_QUIET = 0
@@ -42,17 +45,17 @@ VERBOSE_LEVEL_MAX = 2
 # If there's a file data/gwakeonlan.png then the shared data are searched in
 # relative paths, else the standard paths are used
 if os.path.isfile(os.path.join('data', 'gwakeonlan.png')):
-  DIR_PREFIX = '.'
-  DIR_LOCALE = os.path.join(DIR_PREFIX, 'locale')
-  DIR_DOCS = os.path.join(DIR_PREFIX, 'doc')
+    DIR_PREFIX = '.'
+    DIR_LOCALE = os.path.join(DIR_PREFIX, 'locale')
+    DIR_DOCS = os.path.join(DIR_PREFIX, 'doc')
 else:
-  DIR_PREFIX = os.path.join(sys.prefix, 'share', 'gwakeonlan')
-  DIR_LOCALE = os.path.join(sys.prefix, 'share', 'locale')
-  DIR_DOCS = os.path.join(sys.prefix, 'share', 'doc', 'gwakeonlan')
+    DIR_PREFIX = os.path.join(sys.prefix, 'share', 'gwakeonlan')
+    DIR_LOCALE = os.path.join(sys.prefix, 'share', 'locale')
+    DIR_DOCS = os.path.join(sys.prefix, 'share', 'doc', 'gwakeonlan')
 # Set the paths for the folders
 DIR_DATA = os.path.join(DIR_PREFIX, 'data')
 DIR_UI = os.path.join(DIR_PREFIX, 'ui')
-DIR_SETTINGS = BaseDirectory.save_config_path(DOMAIN_NAME)
+DIR_SETTINGS = xdg.BaseDirectory.save_config_path(DOMAIN_NAME)
 # Set the paths for the UI files
 FILE_UI_MAIN = os.path.join(DIR_UI, 'main.glade')
 FILE_UI_DETAIL = os.path.join(DIR_UI, 'detail.glade')
@@ -61,6 +64,7 @@ FILE_UI_ABOUT = os.path.join(DIR_UI, 'about.glade')
 FILE_UI_APPMENU = os.path.join(DIR_UI, 'appmenu.ui')
 # Set the paths for the data files
 FILE_ICON = os.path.join(DIR_DATA, 'gwakeonlan.png')
+FILE_CONTRIBUTORS = os.path.join(DIR_DOCS, 'contributors')
 FILE_TRANSLATORS = os.path.join(DIR_DOCS, 'translators')
 FILE_LICENSE = os.path.join(DIR_DOCS, 'license')
 FILE_RESOURCES = os.path.join(DIR_DOCS, 'resources')
